@@ -62,6 +62,7 @@ bool GeneratePage::unpackArchive(const KArchiveDirectory *dir, const QString &de
 
     int progress = 0;
 
+    bool failed = false;
     foreach (const QString &entry, entries) {
         progress++;
         ui_generate.progressBar->setValue((progress / entries.size()) * 100);
@@ -73,7 +74,7 @@ bool GeneratePage::unpackArchive(const KArchiveDirectory *dir, const QString &de
             continue;
 
         if (dir->entry(entry)->isDirectory()) {
-            const KArchiveDirectory *file = (KArchiveDirectory *)dir->entry(entry);
+            const KArchiveDirectory *file = dynamic_cast<const KArchiveDirectory *>(dir->entry(entry));
             QString newdest = dest + "/" + file->name();
             if (!QFileInfo(newdest).exists()) {
                 if (!QDir::root().mkdir(newdest)) {
@@ -84,18 +85,29 @@ bool GeneratePage::unpackArchive(const KArchiveDirectory *dir, const QString &de
             ret |= unpackArchive(file, newdest);
         }
         else if (dir->entry(entry)->isFile()) {
-            const KArchiveFile *file = (KArchiveFile *)dir->entry(entry);
+            const KArchiveFile *file = dynamic_cast<const KArchiveFile *>(dir->entry(entry));
             file->copyTo(tdir.path());
             QString destName = KMacroExpander::expandMacros(dest + '/' + file->name(), m_variables);
             if (QFile(QDir::cleanPath(tdir.path() + '/' + file->name())).copy(destName)) {
                 if (!extractFileMacros(destName)) {
-                    displayError(i18n("The extraction of your personal information in file %1 was not successful", destName));
+                    displayError(i18n("Failed to integrate your project information into "
+                                      "the file %1. The project has not be generated and "
+                                      "all temporary files will be removed.", destName));
+                    failed = true;
+                    break;
                 }
             } else {
                 displayError(i18n("Could not copy template file to %1.", destName));
+                failed = true;
+                break;
             }
         }
     }
+
+    if (failed && !QDir(dest).removeRecursively()) {
+        qCDebug(KAPPTEMPLATE) << "Failed to remove incomplete destination directory" << dest;
+    }
+
     return ret;
 }
 
